Statement_Writeln,Statement_Write = print statements for single line and new line,
__________ 

If_these_equals_then = if statement,

_______________________________________

WhenREALrun = infinite loop,

__________________________

Code_Rewrite_with = replace,

Reverse_text,

User_Input_Get,

intTOstring,

stringToint,

Init_op_System,
System_Beep,